import { Transformer, TransformerContext } from "graphql-transformer-core";
import { FieldDefinitionNode, ObjectTypeDefinitionNode, DirectiveNode } from "graphql";
export declare class DefaultValueTransformer extends Transformer {
    constructor();
    /**
     * When a field is annotated with @default(value: "value") the mapping template will default if not set by the user.
     *
     * Usage:
     *
     * type Post @model {
     *   id: ID!
     *   title: String @default(value: "Hello World")
     *   version: Int!
     * }
     *
     * If a value is set by the client, use that, otherwise
     * default to what is in the value of the @default directive.
     */
    field: (parent: ObjectTypeDefinitionNode, def: FieldDefinitionNode, directive: DirectiveNode, ctx: TransformerContext) => void;
    /**
     * Set the field to the default value on create if not set otherwise.
     * @param ctx
     * @param typeName
     * @param fieldName
     * @param defaultValue
     */
    private augmentCreateMutation;
}
